# Wagtail 4.2 release notes - IN DEVELOPMENT

_Unreleased_

```{contents}
---
local:
depth: 1
---
```

## What's new


### Other features

 * Switch to using [Willow](https://github.com/wagtail/Willow/) instead of Pillow for images (Darrel O'Pry)
 * Test assertion [`WagtailPageTestCase.assertCanCreate`](testing_reference) now supports the kwarg `publish=True` to check publish redirection (Harry Percival, Akua Dokua Asiedu)
 * Ensure that the `rebuild_references_index` command can run without console output if called with `--verbosity 0` (Omerzahid Ali, Aman Pandey)
 * Add full support for secondary buttons with icons in the Wagtail design system - `button bicolor button--icon button-secondary` including the `button-small` variant (Seremba Patrick)
 * Add [`purge_embeds`](purge_embeds) management command to delete all the cached embed objects in the database (Aman Pandey)

### Bug fixes

 * Make sure workflow timeline icons are visible in high-contrast mode (Loveth Omokaro)
 * Ensure authentication forms (login, password reset) have a visible border in Windows high-contrast mode (Loveth Omokaro)
 * Ensure visual consistency between buttons and links as buttons in Windows high-contrast mode (Albina Starykova)
 * Ensure `ChooserBlock.extract_references` uses the model class, not the model string (Alex Tomkins)
 * Incorrectly formatted link in the documentation for Wagtail community support (Bolarinwa Comfort Ajayi)
 * Ensure logo shows correctly on log in page in Windows high-contrast mode (Loveth Omokaro)
 * Comments notice background overflows its container (Yekasumah)
 * Ensure links within help blocks meet colour contrast guidelines for accessibility (Theresa Okoro)
 * Ensure the skip link (used for keyboard control) meets colour contrast guidelines for accessibility (Dauda Yusuf)
 * Ensure tag fields correctly show in both dark and light Windows high-contrast modes (Albina Starykova)
 * Ensure new tooltips & tooltip menus have visible borders and tip triangle in Windows high-contrast mode (Juliet Adeboye)
 * Ensure there is a visual difference of 'active/current link' vs normal links in Windows high-contrast mode (Mohammad Areeb)
 * Avoid issues where trailing whitespace could be accidentally removed in translations for new page & snippet headers (Florian Vogt)
 * Make sure minimap error indicators follow the minimap scrolling (Thibaud Colas)

### Documentation

 * Add custom permissions section to permissions documentation page (Dan Hayden)
 * Wagtail's documentation (v2.9 to v4.0) has been updated on [Dash user contributions](https://github.com/Kapeli/Dash-User-Contributions) for [Dash](https://kapeli.com/dash) or [Zeal](https://zealdocs.org/) offline docs applications (Damilola Oladele, Mary Ayobami, Elizabeth Bassey)
 * Add documentation for how to get started with [contributing translations](contributing_translations) for the Wagtail admin (Ogunbanjo Oluwadamilare)
 * Officially recommend `fnm` over `nvm` in development documentation (LB (Ben) Johnston)
 * Mention the importance of passing `request` and `current_site` to `get_url` on the [performance](performance) documentation page (Jake Howard)
 * Add documentation for [`register_user_listing_buttons`](register_user_listing_buttons) hook (LB (Ben Johnston))
 * Add development (contributing to Wagtail) documentation notes for [development on Windows](development_on_windows) (Akua Dokua Asiedu)

### Maintenance

 * Upgrade to Node 18 for frontend build tooling (LB (Ben) Johnston)
 * Run Python tests with coverage and upload coverage data to codecov (Sage Abdullah)
 * Clean up duplicate JavaScript for the `escapeHtml` function (Jordan Rob)
 * Ensure that translation file generation ignores JavaScript unit tests and clean up unit tests for Django gettext utils (LB (Ben Johnston))
 * Migrated `initButtonSelects` from core.js to own TypesScript file and add unit tests (Loveth Omokaro)
 * Migrated `initSkipLink` util to TypeScript and add JSDoc & unit tests (Juliet Adeboye)
 * Clean up some unused utility classes and migrate `unlist` to Tailwind utility class `w-list-none` (Loveth Omokaro)
 * Clean up linting on legacy code and add shared util `hasOwn` in TypeScript (Loveth Omokaro)
 * Remove unnecessary box-sizing: border-box declarations in SCSS (Albina Starykova)
 * Migrated `initTooltips` to TypeScript add JSDoc and unit tests (Fatuma Abdullahi)
 * Migrated `initTagField` from core.js to own TypeScript file and add unit tests (Chisom Okeoma)

## Upgrade considerations

### Wagtail-specific image field (`WagtailImageField`)

The `AbstractImage` and `AbstractRendition` models use a Wagtail-specific `WagtailImageField` which extends Django's `ImageField` 
to use [Willow](https://github.com/wagtail/Willow/) for image file handling. This will generate a new migration if you 
are using a [custom image model](custom_image_model)
